# Generated by Django 1.10 on 2017-01-03 16:11

from django.contrib.postgres.fields import JSONField
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('elasticsearch_django', '0004_auto_20161129_1135'),
    ]

    operations = [
        migrations.AlterField(
            model_name='searchquery',
            name='hits',
            field=JSONField(
                help_text='The list of meta info for each of the query matches returned.'
            ),
        ),
        migrations.AlterField(
            model_name='searchquery',
            name='query',
            field=JSONField(help_text='The raw ElasticSearch DSL query.'),
        ),
    ]



# Generated by Django 2.0.5 on 2018-08-03 16:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('elasticsearch_django', '0007_update_json_field_encoders'),
    ]

    operations = [
        migrations.AddField(
            model_name='searchquery',
            name='search_terms',
            field=models.CharField(
                blank=True,
                default='',
                help_text='Free text search terms used in the query, stored for easy reference.',
                max_length=400
            ),
        ),
    ]
